@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2011-2023 The Octave Project Developers
+// Copyright (C) 2011-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -35,26 +35,29 @@
 OCTAVE_BEGIN_NAMESPACE(octave)
 
 FigureWindow::FigureWindow (QWidget *xparent)
-: FigureWindowBase (xparent)
+  : FigureWindowBase (xparent)
 {
-  // set icon from application resources
-  setWindowIcon (QIcon (global_icon_paths.at (ICON_THEME_OCTAVE)));
+  // Set icon from application resources. Since FigureWindow is also used by
+  // msgbox (in turn used be hekodlg, warndlg, ...), the logo should be the
+  // neutral octave icon:
+  setWindowIcon (QIcon (global_icon_paths.at (ICON_THEME_OCTAVE) + "logo.png"));
 }
 
-FigureWindow::~FigureWindow (void)
+FigureWindow::~FigureWindow ()
 { }
 
 QMenu *
-FigureWindow::createPopupMenu (void)
+FigureWindow::createPopupMenu ()
 {
   // For the time being, disable menubar/toolbar popup menu
   return nullptr;
 }
 
-void FigureWindow::showEvent (QShowEvent *ev)
+void
+FigureWindow::showEvent (QShowEvent *ev)
 {
   QMainWindow::showEvent (ev);
-  emit figureWindowShown();
+  Q_EMIT figureWindowShown ();
 }
 
 OCTAVE_END_NAMESPACE(octave)
