@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2024 The Octave Project Developers
+// Copyright (C) 1996-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -40,12 +40,8 @@ OCTAVE_BEGIN_NAMESPACE(octave)
 
 // Simple assignment expressions.
 
-tree_simple_assignment::tree_simple_assignment (tree_expression *le,
-    tree_expression *re,
-    bool plhs, int l, int c,
-    octave_value::assign_op t)
-  : tree_expression (l, c), m_lhs (le), m_rhs (re), m_preserve (plhs),
-    m_ans_assign (), m_etype (t)
+tree_simple_assignment::tree_simple_assignment (tree_expression *le, tree_expression *re, bool plhs, octave_value::assign_op t)
+  : m_lhs (le), m_rhs (re), m_preserve (plhs), m_ans_assign (), m_etype (t)
 { }
 
 tree_simple_assignment::~tree_simple_assignment ()
@@ -153,10 +149,8 @@ tree_simple_assignment::evaluate (tree_evaluator& tw, int)
 
 // Multi-valued assignment expressions.
 
-tree_multi_assignment::tree_multi_assignment (tree_argument_list *lst,
-    tree_expression *r,
-    bool plhs, int l, int c)
-  : tree_expression (l, c), m_lhs (lst), m_rhs (r), m_preserve (plhs)
+tree_multi_assignment::tree_multi_assignment (tree_argument_list *lst, tree_expression *r, bool plhs)
+  : m_lhs (lst), m_rhs (r), m_preserve (plhs)
 { }
 
 tree_multi_assignment::~tree_multi_assignment ()
@@ -176,7 +170,8 @@ tree_multi_assignment::oper () const
 tree_expression *
 tree_multi_assignment::dup (symbol_scope&) const
 {
-  panic_impossible ();
+  error ("unexpected call to tree_multi_assignment::dup - please report this bug");
+
   return nullptr;
 }
 
