@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1994-2020 The Octave Project Developers
+// Copyright (C) 1994-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -196,19 +196,19 @@ ComplexColumnVector::stack (const ComplexColumnVector& a) const
 }
 
 ComplexRowVector
-ComplexColumnVector::hermitian (void) const
+ComplexColumnVector::hermitian () const
 {
   return MArray<Complex>::hermitian (std::conj);
 }
 
 ComplexRowVector
-ComplexColumnVector::transpose (void) const
+ComplexColumnVector::transpose () const
 {
   return MArray<Complex>::transpose ();
 }
 
 ColumnVector
-ComplexColumnVector::abs (void) const
+ComplexColumnVector::abs () const
 {
   return do_mx_unary_map<double, Complex, std::abs> (*this);
 }
@@ -262,7 +262,7 @@ ComplexColumnVector::operator += (const ColumnVector& a)
   if (len == 0)
     return *this;
 
-  Complex *d = fortran_vec (); // Ensures only one reference to my privates!
+  Complex *d = rwdata (); // Ensures only one reference to my privates!
 
   mx_inline_add2 (len, d, a.data ());
   return *this;
@@ -281,7 +281,7 @@ ComplexColumnVector::operator -= (const ColumnVector& a)
   if (len == 0)
     return *this;
 
-  Complex *d = fortran_vec (); // Ensures only one reference to my privates!
+  Complex *d = rwdata (); // Ensures only one reference to my privates!
 
   mx_inline_sub2 (len, d, a.data ());
   return *this;
@@ -317,7 +317,7 @@ operator * (const ComplexMatrix& m, const ComplexColumnVector& a)
         retval.fill (0.0);
       else
         {
-          Complex *y = retval.fortran_vec ();
+          Complex *y = retval.rwdata ();
 
           F77_XFCN (zgemv, ZGEMV, (F77_CONST_CHAR_ARG2 ("N", 1),
                                    nr, nc, 1.0,
@@ -420,7 +420,7 @@ operator * (const ComplexDiagMatrix& m, const ComplexColumnVector& a)
 // other operations
 
 Complex
-ComplexColumnVector::min (void) const
+ComplexColumnVector::min () const
 {
   octave_idx_type len = numel ();
   if (len == 0)
@@ -440,7 +440,7 @@ ComplexColumnVector::min (void) const
 }
 
 Complex
-ComplexColumnVector::max (void) const
+ComplexColumnVector::max () const
 {
   octave_idx_type len = numel ();
   if (len == 0)
