@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1995-2022 The Octave Project Developers
+// Copyright (C) 1995-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,7 +32,7 @@
 #include "MArray.h"
 #include "MArray.cc"
 
-INSTANTIATE_MARRAY (double, OCTAVE_API);
+INSTANTIATE_MARRAY (double, OCTARRAY_CLASS_TEMPLATE_INSTANTIATION_API);
 
 INSTANTIATE_MARRAY_FRIENDS (double, OCTAVE_API)
 
