@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2024 The Octave Project Developers
+// Copyright (C) 2016-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -26,20 +26,20 @@
 #if ! defined (octave_vasprintf_wrapper_h)
 #define octave_vasprintf_wrapper_h 1
 
-#if defined __cplusplus
+#if defined (__cplusplus)
 #  include <cstdarg>
 #else
 #  include <stdarg.h>
 #endif
 
-#if defined __cplusplus
+#if defined (__cplusplus)
 extern "C" {
 #endif
 
 extern OCTAVE_API int
 octave_vasprintf_wrapper (char **buf, const char *fmt, va_list args);
 
-#if defined __cplusplus
+#if defined (__cplusplus)
 }
 #endif
 
