@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2007-2023 The Octave Project Developers
+## Copyright (C) 2007-2025 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -88,6 +88,20 @@ function T = delaunayn (pts, varargin)
     T = __delaunayn__ (pts, varargin{:});
   endif
 
+  ## Avoid erroneous calculations due to integer truncation.  See bug #64658.
+  ## FIXME: Large integer values in excess of flintmax can lose precision
+  ##        when converting from (u)int64 to double.  Consider modifying
+  ##        simplex checking to account for large integer math to avoid this
+  ##        problem.
+  if (isinteger (pts))
+    if (any (abs (pts(:)) > flintmax ('double')))
+      warning (["delaunayn: conversion of large integer values to ", ...
+                "double, potential loss of precision may result in " ...
+                "erroneous triangulations."]);
+    endif
+    pts = double (pts);
+  endif
+
   ## Begin check for and removal of trivial simplices
   if (! isequal (T, 0))  # skip trivial simplex check if no simplexes
 
@@ -234,6 +248,13 @@ endfunction
 %!            (edges(:,1,2) .* edges(:,2,3) - edges(:,2,2) .* edges(:,1,3));
 %! assert (all (vol >= 0));
 
+## Avoid integer input erroneous volume truncation
+%!testif HAVE_QHULL <*64658>
+%! pts = [0 0 0; 0 0 10; 0 10 0; 0 10 10; 10 0 0; ...
+%!              10 0 10; 10 10 0; 10 10 10; 5 5 5];
+%! assert (isempty (delaunayn (int32 (pts))), false);
+%! assert (delaunayn (pts), delaunayn (int32 (pts)));
+
 ## Input validation tests
 %!error <Invalid call> delaunayn ()
 %!error <input PTS must be> delaunayn ("abc")
