@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2012-2023 The Octave Project Developers
+// Copyright (C) 2012-2025 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -46,15 +46,18 @@
 
 #include "liboctgui-build-info.h"
 
+#include "liboctmex-build-info.h"
+
 #include "oct-env.h"
 
 #include "octave.h"
 #include "octave-build-info.h"
 #include "qt-application.h"
 #include "sysdep.h"
+#include "version.h"
 
 static void
-check_hg_versions (void)
+check_hg_versions ()
 {
   bool ok = true;
 
@@ -67,6 +70,7 @@ check_hg_versions (void)
   std::string liboctave_id = liboctave_hg_id ();
   std::string liboctinterp_id = liboctinterp_hg_id ();
   std::string liboctgui_id = liboctgui_hg_id ();
+  std::string liboctmex_id = liboctmex_hg_id ();
 
   if (octave_id != liboctave_id)
     {
@@ -98,6 +102,16 @@ check_hg_versions (void)
       ok = false;
     }
 
+  if (octave_id != liboctmex_id)
+    {
+      std::cerr << "octave hg id ("
+                << octave_id
+                << ") does not match liboctmex hg id ("
+                << liboctmex_id
+                << ')' << std::endl;
+      ok = false;
+    }
+
   if (! ok)
     exit (1);
 }
@@ -143,7 +157,13 @@ main (int argc, char **argv)
 
   octave::sys::env::set_program_name (argv[0]);
 
-  octave::qt_application app (argc, argv);
+  std::string app_name ("octave-gui");
+  std::string settings_file = octave::sys::env::getenv ("OCTAVE_GUI_SETTINGS");
+  if (! settings_file.empty ())
+    app_name = settings_file;
+
+  octave::qt_application app ("octave", app_name, OCTAVE_VERSION,
+                              argc, argv);
 
   int ret = app.execute ();
 
